@@ -40,7 +40,7 @@ class Backup(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res["spec"] = {}
             spec_dict = self.res["spec"]
 
